__title__ = 'transliterate.defaults'
__version__ = '1.5'
__build__ = 0x00000F
__author__ = 'Artur Barseghyan'
__all__ = ('LANGUAGES_DIR', 'CONTRIB_DIR', 'LANGUAGE_PACK_MODULE_NAME', 'LANGUAGE_DETECTION_MAX_NUM_KEYWORDS', 'DEBUG')

LANGUAGES_DIR = ('contrib', 'languages')
CONTRIB_DIR =  ('contrib', 'apps')
LANGUAGE_PACK_MODULE_NAME = 'translit_language_pack'
LANGUAGE_DETECTION_MAX_NUM_KEYWORDS = 16

DEBUG = False
